function or_pdf(urlr)
% OR_PDF Pdf-s of the local shapes orientation
% 
% Note: This is a subfunction of or_wrap.
% 
% -------------
% INPUT
% -------------
% urlr - text file with the frequency count of
%     the orientation measurements
%     format: filename tab angle-in-degrees tab ... \n
% 
% -------------
% OUTPUT
% -------------
% {url}_pdf.txt - text file with the orientation pdf
%     format: filename tab probability tab ... \n
%     - save location: 'dat' directory relative to urlr file location
% 
% -------------
% CREDITS
% -------------
% Vlad Atanasiu
% atanasiu@alum.mit.edu | http://www.waqwaq.info/atanasiu/
% 2010.12.27 - creation

% initializations
datdir = 'dat/';

% compose file name to be created by this function
[fpath, fname] = fileparts(urlr);
% file is in the current workdirectory
if ~isempty(fpath)
    fpath = [fpath '/'];
end
% compose output locations
if exist([fpath datdir],'dir') == 0
    mkdir([fpath datdir])
end
urlw = [fpath datdir fname '_or_pdf.txt'];

% delete any previous raw data file with the same name
if exist(urlw,'file') > 0
    delete(urlw);
end

% read data file
data = importdata([fpath datdir fname '_or_frq.txt']);
sz = size(data.data,1);

% display waitbar
hwb = waitbar(0,'');
set(hwb,'Name','The machine is working... Drink coffee.')
waitbar(0, hwb,['0 / ' num2str(sz) ' steps'])
drawnow

% batch process data
for id = 1:sz
    % read frequency data
    F = data.data(id,:);
    
    % convert frequencies to raw data
    R = [];
    for k = 1:180
        R = [R; ones(F(k),1)*(k-1)];
    end
    
    % compute pdf
    P = circ_ksdensity(R, 0:179, 'msni');

    % save results to file
    % (if the file exists the new data is appended)
    fname = char(data.textdata(id,:));
    P = P';
    s = regexprep(mat2str(P),'\s','\t');
    s = [fname '\t' s(2:end-1) '\n'];
    fid = fopen(urlw,'at');
    fprintf(fid, s);
    fclose(fid);

    % increment waitbar
    waitbar(id/sz, hwb, [num2str(id) ' / ' num2str(sz) ' images'])
end
close(hwb)

