function I = or_pre(I,preproc,stroke_type)
% OR_PRE Preprocess images for local orientation measurements
% 
% -------------
% INPUT
% -------------
% I1 - input image
% preproc   - string: 'preprocess' | {'nopreprocess'}
%           - option to preprocess the input images:
%           binarization, negative, [resizing]
% stroke_type - string: {'outlines'} | 'inline'
%           - extract the outlines or inline of the shape
% 
% -------------
% OUTPUT
% -------------
% I2 - output image
% 
% -------------
% CREDITS
% -------------
% Vlad Atanasiu
% atanasiu@alum.mit.edu | http://www.waqwaq.info/atanasiu/
% 2011.08.05 - [new] activate outlines/inline option
% 2010.12.27 - creation

% parse inputs
if nargin < 2
    preproc = 'preprocess';
end
if nargin < 3
    stroke_type = 'outlines';
end

% do preprocessing
if strcmp(preproc,'preprocess')
    % resize image if necessary
    % I = imresize(I, .3, 'bicubic'); % subsampling
    % I = imresize(I, 4, 'bicubic'); % supersampling

    % convert to grayscale if necessary
    if length(size(I)) == 3
        I = rgb2gray(I);
    else
        % avoid variable class conflicts
        I = double(I);
    end

    % binarize image if necessary
    if numval(I) > 2
        I = im2bw(I, graythresh(I));
    end
    
    % text_blackboard needs logical
    I = logical(I);
    
    % make negative image
    I = text_blackboard(I);
end

% make outlines or inline
if strcmp(stroke_type,'outlines')
    I = bwmorph(I, 'remove');
else
    I = bwmorph(I, 'skel', Inf);
end

% % % make logical
% % I = logical(I);
% % % make negative image
% % I = text_blackboard(I);

% show result
% figure, imagesc(I), axis image, colormap(gray)


