function [L, url] = read_imageslist(url)
%READ_IMAGESLIST Reads images paths from a text file w/{o} GUI.
% 
% -------------
% INPUT
% -------------
% url - string; url of text file with image files names
%     - file format: file name \r\n file name ...
%     - Input argument is optional; if none is supplied
%       a GUI lets you select either a text file with the
%       urls (batch mode) or a single image file.
%     - If you select any other file than one having the 'txt'
%       extension, then the path to this file will be the output.
% 
% -------------
% OUTPUT
% -------------
% L - Cell array of strings containing the paths to the images.
% url - The url to the selected file. This is useful if your
%       selection was via the GUI and you need to know url
%       of the selected file during later parts of your code.
% 
% -------------
% CREDITS
% -------------
% Vlad Atanasiu
% atanasiu@alum.mit.edu | http://www.waqwaq.info/atanasiu/
% 2010.12.27 - creation

% interactive selection of data to read
if nargin < 1
    % select image of allowed file formats
    [filename,pathname] = uigetfile(...
       {'*.txt',        ['> ','List']; ...
        '*.jpg;*.jpeg;*.tif;*.tiff;*.bmp;*.png;*.pcx;*.hdf;*.xwd',...
                        ['> ','Images']; ...
        '*.jpg;*.jpeg', 'JPG, JPEG';...
        '*.tif;*.tiff', 'TIFF, TIFF'; ...
        '*.bmp',        'BMP'; ...
        '*.png',        'PNG'; ...
        '*.pcx',        'PCX'; ...
        '*.hdf',        'HDF'; ...
        '*.xwd',        'XWD'; ...
        '*.*',          ['All Files',' (*.*)']}, ...
        ['AD751 - ','Load images']);

    if ~isempty(filename) || ~isempty(pathname);
        url = [pathname,filename];
        [~,~,ext] = fileparts(url);
        % reads list of files if any
        if strcmp(ext,'.txt') == 1
            try
                L = importdata(url);
            catch
                errordlg('File Reading Error','modal');
                return
            end
        % creates path for single image
        else
            L = {url};
        end
    else
        errordlg('No file chosen. By by!','modal');
    end
% programatic data reading
else
    L = importdata(url);
end
